@@ -2,7 +2,7 @@ from .SecurityLayer import SecurityLayer
 from .AccessControl import *
 from .Error import *
 from dtwentyORM import Metadata
-from Communications.Communications import Communications
+from dtwentyCommunications import Communications
 from flask import request, redirect, url_for
 import json
 import datetime
